```bash
whisper-client -k tiens_félix_essaie_avec_cette_clé -s http -H 192.168.2.2 -p 5464 --stdout -V "/home/marceau/PycharmProjects/Pellipop/videos-collecte1"
```

```bash
whisper-client -k tiens_félix_essaie_avec_cette_clé -s https -H whisper.marceau-h.fr -p 443 -I 7206340881052372229.wav --stdout
```

```bash
whisper-client -k tiens_félix_essaie_avec_cette_clé -s https -H whisper.marceau-h.fr -p 443 -V "/home/marceau/PycharmProjects/Pellipop/videos-collecte1"
```

```bash
whisper-client -k tiens_félix_essaie_avec_cette_clé -s https -H whisper.marceau-h.fr -p 443 -A "/home/marceau/PycharmProjects/Pellipop/videos-collecte1/extracted_audio"
```
